import {
  reactive,
  computed,
  onMounted,
} from 'vue'
import request from '../../utils/request'

// 户型
const roomType = [{
    text: '一室',
    value: '1',
  },
  {
    text: '两室',
    value: '2',
  },
  {
    text: '三室',
    value: '3',
  },
  {
    text: '三室以上',
    value: '4',
  },
]

// 实勘状态
const rescStatus = [{
    text: '已实勘',
    value: '0',
  },
  {
    text: '待审核',
    value: '1',
  },
  {
    text: '未实勘',
    value: '9',
  },
]

// 钥匙状态
const keyStatus = [{
    text: '有钥匙',
    value: '0',
  },
  {
    text: '待审核',
    value: '1',
  },
  {
    text: '无钥匙',
    value: '9',
  },
]

// 业主委托
const authStatus = [{
    text: '有委托',
    value: '0',
  },
  {
    text: '待审核',
    value: '1',
  },
  {
    text: '无委托',
    value: '9',
  },
]

// 电梯
const elevator = [{
    text: '有',
    value: '0',
  },
  {
    text: '无',
    value: '1',
  },
]

// 带看
const lookTimes = [{
    text: '有',
    value: '1',
  },
  {
    text: '无',
    value: '0',
  },
]

// 锁盘
const lockRoom = [{
    text: '未锁盘',
    value: '0',
  },
  {
    text: '锁盘已关联',
    value: '1',
  },
  {
    text: '锁盘未关联',
    value: '2',
  },
]

//租房类型
const leaseWay = [{
    text: '整租',
    value: '0',
  },
  {
    text: '合租',
    value: '1',
  },
]

export default () => {
  const dicts = reactive({
    roomType,
    rescStatus,
    keyStatus,
    authStatus,
    elevator,
    lookTimes,
    lockRoom,
    leaseWay,
  })

  const getDict = (key) => {
    request({
      url: '/comm/dict',
      params: {
        groupCode: key
      },
    }).then((res) => {
      dicts[key] = (res || []).map((x) => ({
        text: x.name,
        value: x.code
      }))
    })
  }

  //
  const getBusinessCity = (areaType, pcode) => {
    if (1 === areaType) {
      pcode = '025'
    }

    request({
      url: '/comm/dict/business-city',
      params: {
        areaType,
        pcode
      },
    }).then((res) => {
      if (1 === areaType) {
        // 区县
        dicts['roomDistrict'] = res
      } else {
        // 商圈
        dicts['roomBussines'] = res
      }
    })
  }

  const getBuilding = ({
    buildingName,
    pageNo = 1,
    pageSize = 20
  }) => {
    return request({
      url: '/comm/dict/building-list',
      params: {
        buildingName,
        pageNo,
        pageSize
      },
    }).then((res) => {
      if (res.result && res.result.length && !buildingName && pageNo === 1) {
        // 只缓存第一页的
        dicts['building'] = res.result
      }

      return res
    })
  }

  // 装修
  const decorationOptions = computed(() => {
    const decorationDict = dicts.decoration || []
    if (!decorationDict.length) {
      getDict('decoration')
    }

    return decorationDict
  })

  // 朝向
  const aspectOptions = computed(() => {
    const aspectDict = dicts.aspect || []
    if (!aspectDict.length) {
      getDict('aspect')
    }

    return aspectDict
  })

  // 房源来源
  const sourceFromOptions = computed(() => {
    const sourceFromDict = dicts.sourceFrom || []
    if (!sourceFromDict.length) {
      getDict('sourceFrom')
    }

    return sourceFromDict
  })

  // 建筑类型
  const buildTypeOptions = computed(() => {
    const buildTypeDict = dicts['build_type'] || []
    if (!buildTypeDict.length) {
      getDict('build_type')
    }

    return buildTypeDict
  })

  // 电梯
  const elevatorOptions = dicts.elevator

  // 交易属性
  const natureOptions = computed(() => {
    const natureDict = dicts.nature || []
    if (!natureDict.length) {
      getDict('nature')
    }

    return natureDict
  })

  // 房屋用途
  const purposeOptions = computed(() => {
    const purposeDict = dicts.purpose || []
    if (!purposeDict.length) {
      getDict('purpose')
    }

    return purposeDict
  })

  // 抵押信息
  const mortgageOptions = computed(() => {
    const mortgageDict = dicts.mortgage || []
    if (!mortgageDict.length) {
      getDict('mortgage')
    }

    return mortgageDict
  })

  // 税费
  const buildTimeOptions = computed(() => {
    const buildTimeDict = dicts['build_time'] || []
    if (!buildTimeDict.length) {
      getDict('build_time')
    }

    return buildTimeDict
  })

  // 隔断
  const separateOptions = computed(() => {
    const separateDict = dicts['separate'] || []
    if (!separateDict.length) {
      getDict('separate')
    }

    return separateDict
  })

  // 付款方式
  const payWayOptions = computed(() => {
    const payWayDict = dicts['payWay'] || []
    if (!payWayDict.length) {
      getDict('payWay')
    }

    return payWayDict
  })

  // 居住现状
  const liveStatusOptions = computed(() => {
    const liveStatusDict = dicts['liveStatus'] || []
    if (!liveStatusDict.length) {
      getDict('liveStatus')
    }

    return liveStatusDict
  })

  // 卧室
  const livingRoomOptions = computed(() => {
    const livingRoomDict = dicts['livingRoom'] || []
    // if (!livingRoomDict.length) {
    //   getDict('livingRoom')
    // }

    return livingRoomDict
  })

  const loadDictOnMount = () =>
    onMounted(() => {
      if (!livingRoomOptions.value.length) {
        getDict('livingRoom')
      }
    })

  // 限制性别
  const limitSexOptions = computed(() => {
    const limitSexDict = dicts['limitSex'] || []
    if (!limitSexDict.length) {
      getDict('limitSex')
    }

    return limitSexDict
  })

  // 房屋特色
  const roomSpecialOptions = computed(() => {
    const roomSpecialDict = dicts['roomSpecial'] || []
    if (!roomSpecialDict.length) {
      getDict('roomSpecial')
    }

    return roomSpecialDict
  })

  // 限制性别
  const parkingOptions = computed(() => {
    const parkingDict = dicts['parking'] || []
    if (!parkingDict.length) {
      getDict('parking')
    }

    return parkingDict
  })

  // 房屋特色
  const basementOptions = computed(() => {
    const basementDict = dicts['basement'] || []
    if (!basementDict.length) {
      getDict('basement')
    }

    return basementDict
  })

  // 限制性别
  const gasOptions = computed(() => {
    const gasDict = dicts['gas'] || []
    if (!gasDict.length) {
      getDict('gas')
    }

    return gasDict
  })

  // 房屋特色
  const electricEquipmentOptions = computed(() => {
    const electricEquipmentDict = dicts['electricEquipment'] || []
    if (!electricEquipmentDict.length) {
      getDict('electricEquipment')
    }

    return electricEquipmentDict
  })

  const namedDicts = reactive({
    decorationOptions,
    aspectOptions,
    sourceFromOptions,
    buildTypeOptions,
    elevatorOptions,
    natureOptions,
    purposeOptions,
    mortgageOptions,
    buildTimeOptions,
    separateOptions,
    payWayOptions,
    liveStatusOptions,
    livingRoomOptions,
    limitSexOptions,
    roomSpecialOptions,
    parkingOptions,
    basementOptions,
    gasOptions,
    electricEquipmentOptions,
  })

  return {
    dicts,
    namedDicts,
    getDict,
    getBusinessCity,
    getBuilding,
    loadDictOnMount,
  }
}