import axios from 'axios'
import { Toast } from 'vant'
import { router } from '@/router'
import store from '@/store'
import { showDanger } from '../'

// request 拦截器
const requestInterceptor = (config) => {
  const loading = store.getState('loading')

  if (config.loadingId) {
    config.setLoading = (state) => loading.setLoading(config.loadingId, state)
    config.setLoading(true)
  }

  if (config.toast) {
    config.toastInst = Toast.loading({
      message: config.toast,
      forbidClick: true,
      overlay: true,
      duration: 0,
    })
  }

  return config
}

// response 拦截器
const responseInterceptor = (response) => {
  const { data, headers } = response
  const contentType = headers['Content-Type'] || headers['content-type'] || ''
  console.log(headers, 'headers')

  if (response.config.setLoading) {
    response.config.setLoading(false)
  }

  if (response.config.toastInst) {
    response.config.toastInst.clear()
  }

  if (/json/.test(contentType)) {
    if ('0' === data.code) {
      return data.data
    } else if ('-1' === data.code) {
      router.push('/login')
      // return Promise.reject(data.message)
    } else {
      return Promise.reject(data)
    }
  } else {
    console.log(data, 'router1')
    if ('-1' === data.code) {
      console.log(router, 'router')
      router.push('/login')
      // return
      return Promise.reject(data.message)
    }
    return Promise.reject('账号未登录或没有权限')
  }
}

// 错误处理
const handleError = (type) => (error) => {
  console.error(error)
  if (error.config.setLoading) {
    error.config.setLoading(false)
  }

  if (error.config.toastInst) {
    error.config.toastInst.clear()
  }

  if (error.response) {
    console.error(`[${type}]:`)
    console.error(error.response)
    showDanger(`错误的请求 - [${error.status || error.message}]`)
  } else {
    const errorMessage = error.message || error.msg || error
    console.error(`[${type}] ${errorMessage}`)
    return Promise.reject(errorMessage)
  }
}

const request = axios.create({
  // 通用前缀
  baseURL: '/mp',
  // 允许 cookie
  withCredentials: true,
  // 全部都是 post 请求
  method: 'post',
})

request.interceptors.request.use(requestInterceptor, handleError('REQUEST'))
request.interceptors.response.use(responseInterceptor, handleError('RESPONSE'))

export default request
